import React, {useEffect, useState} from "react"
import '@material/web/textfield/outlined-text-field'
import '@material/web/fab/fab'
import '@material/web/icon/icon'
import '@material/web/select/outlined-select'
import '@material/web/select/select-option'
import '@material/web/list/list'
import '@material/web/list/list-item'

import FullScreenDialog from "../components/FullScreenDialog"
import PollListItem from "../components/PollListItem"

import './PollsScreen.css'

const PollContext = React.createContext({
    polls: [],
    fetchPolls: () => {},
})

const apiUrl = new URL(location)
apiUrl.pathname = '/api/polls'

export default function PollsScreen() {
    const [polls, setPolls] = useState([])
    const [editPoll, setEditPoll] = useState(false)

    const fetchPolls = async () => {
        const response = await fetch('/api/polls')
        const polls = await response.json()
        setPolls(polls)
    }

    const updatePoll = async (poll) => {
        await fetch(apiUrl, {
            method: 'PUT',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify(poll)
        })
        await fetchPolls()
    }

    useEffect(() => {
        fetchPolls()
    }, [])

    return (
        <section id="polls-screen">

            <md-list>
                <PollContext.Provider value={{polls, fetchPolls}}>
                    {polls.map((poll) => (
                        PollListItem(poll, setEditPoll, updatePoll)
                    ))}
                </PollContext.Provider>
            </md-list>

            <FullScreenDialog
                setEditPoll={setEditPoll}
                classList={editPoll ? 'open' : 'close'}>

                <md-outlined-text-field
                        label="Название"
                        value={editPoll ? editPoll.name : ''}
                        required="required">
                    <md-icon slot="leading-icon">title</md-icon>
                </md-outlined-text-field>

                <md-outlined-select label="Дни недели" required="required">

                    <md-icon slot="leading-icon">date_range</md-icon>

                    <md-select-option value="mon">
                        <div slot="headline">Понедельник</div>
                    </md-select-option>

                    <md-select-option value="tue">
                        <div slot="headline">Вторник</div>
                    </md-select-option>

                    <md-select-option value="wed">
                        <div slot="headline">Среда</div>
                    </md-select-option>

                    <md-select-option value="thu">
                        <div slot="headline">Четверг</div>
                    </md-select-option>

                    <md-select-option value="fri">
                        <div slot="headline">Пятница</div>
                    </md-select-option>

                    <md-select-option value="sat">
                        <div slot="headline">Суббота</div>
                    </md-select-option>

                    <md-select-option value="sun">
                        <div slot="headline">Воскресенье</div>
                    </md-select-option>

                </md-outlined-select>

                <section id="poll-messages">
                    <div className="md-typescale-title-medium">Сообщения</div>
                    <md-list>
                        <md-list-item>
                            Fruits
                        </md-list-item>
                        <md-divider></md-divider>
                        <md-list-item>
                            Apple
                        </md-list-item>
                        <md-list-item>
                            Banana
                        </md-list-item>
                        <md-list-item>
                            <div slot="headline">Cucumber</div>
                            <div slot="supporting-text">Cucumbers are long green fruits that are just as long as this
                                multi-line description
                            </div>
                        </md-list-item>
                        <md-list-item
                            type="link"
                            href="https://google.com/search?q=buy+kiwis&tbm=shop"
                            target="_blank">
                            <div slot="headline">Shop for Kiwis</div>
                            <div slot="supporting-text">This will link you out in a new tab</div>
                            <md-icon slot="end">open_in_new</md-icon>
                        </md-list-item>
                    </md-list>
                </section>

            </FullScreenDialog>

        </section>
    )
}
